@@ -41,7 +41,17 @@ fn main() -> Result<()> {
         &window,
         asche::InstanceConfiguration {
             app_name: "raytracing example",
-            app_version: erupt::vk::make_api_version(0, 1, 0, 0),
+            app_version: asche::Version {
+                major: 1,
+                minor: 0,
+                patch: 0,
+            },
+            engine_name: "engine example",
+            engine_version: asche::Version {
+                major: 1,
+                minor: 0,
+                patch: 0,
+            },
             extensions: vec![],
         },
     )?;
